ScanPolicy

Struct ScanPolicy 

pub struct ScanPolicy {
    pub account_gap_limit: u32,
    pub address_scan_depth: u32,
}
Controls for address discovery and sync behavior.

Fields

account_gap_limit: u32

Number of consecutive unused addresses to skip before stopping scan.

address_scan_depth: u32

Constant number of addresses to scan regardless of activity.